import React from 'react';
import ReactDOM from 'react-dom';
import { useWorldAtlas } from './useWorldAtlas';
import { data } from './useCities';
import { Marks } from './Marks';
import { ColorLegend } from './ColorLegend';
import {
  scaleSequential,
  interpolateViridis,
  extent,
  timeFormat,
  timeDay
} from 'd3';

const width = 960;
const height = 500;
const circleRadius = 5;
const formatDate = timeFormat('%m/%d/%Y');

const App = () => {
  const worldAtlas = useWorldAtlas();

  if (!worldAtlas) {
    return <pre>Loading...</pre>;
  }

  const colorValue = d => d.date;
  const colorExtent = extent(data, colorValue);
  const colorScale = scaleSequential(interpolateViridis).domain(colorExtent);

  return (
    <>
      <svg width={width} height={height}>
        <Marks
          worldAtlas={worldAtlas}
          cities={data}
          colorValue={colorValue}
          colorScale={colorScale}
          circleRadius={circleRadius}
        />
        <g transform={`translate(60, 200)`}>
          <text x={35} y={-25} className="axis-label" textAnchor="middle">
            Date joined
          </text>
          <ColorLegend
            tickSpacing={22}
            tickSize={10}
            tickTextOffset={12}
            tickSize={circleRadius}
            colorScale={colorScale}
            ticks={timeDay.range(colorExtent[0], timeDay.ceil(colorExtent[1])).concat(colorExtent[1])}
            tickFormat={formatDate}
          />
        </g>
      </svg>
      <div className="title">Datavis 2020 Students</div>
      <div className="subtitle">{data.length} in total who introduced themselves with location.</div>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
